Processor.App.processor\_utils.PipeMetadata
===========================================

.. currentmodule:: Processor.App.processor_utils

.. autoclass:: PipeMetadata

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~PipeMetadata.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PipeMetadata.encoding
      ~PipeMetadata.name
      ~PipeMetadata.domain_record
      ~PipeMetadata.article_data
      ~PipeMetadata.warc_header
      ~PipeMetadata.http_header
   
   